@@ -5,8 +5,18 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2008-2021 Statnet Commons
+#  Copyright 2008-2022 Statnet Commons
 ################################################################################
+
+#' @templateVar name staticDiscordTNT
+#' @aliases InitErgmProposal.staticDiscordTNT
+#' @title TNT proposal for CMLE fitting
+#' @description A version of \code{\link[ergm:TNT-ergmProposal]{TNT}} appropriate for CMLE fitting,
+#'   proposals stratified both by discordance status and edge status.  The argument
+#'   `ref` specifies the data relative to which discordance status is defined.
+#' @template ergmProposal-general
+NULL
+
 InitErgmProposal.staticDiscordTNT <- function(arguments, nw, model) {
   dissolvable <- as.rlebdm(arguments$constraints$discord$nw)
   formable <- !dissolvable
