@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2008-2021 Statnet Commons
+#  Copyright 2008-2022 Statnet Commons
 ################################################################################
 # Keeps a list of "named" graphic devices.
 #
@@ -132,7 +132,7 @@ network.extract.with.lasttoggle <- function(nwd, at){
 
 
 to.networkDynamic.lasttoggle <- function(nw){
-  nwd <- nw
+  nwd <- as.networkDynamic(nw)
   if(!is.null(nw %n% "lasttoggle")){
     
     lt.edges <- edgelist_with_lasttoggle(nw)
@@ -140,11 +140,11 @@ to.networkDynamic.lasttoggle <- function(nw){
     lt.edges <- lt.edges[lt.edges[,3]>as.integer(-.Machine$integer.max/2),,drop=FALSE] 
 
     # removed the +1 after lt.edges[,3]
-    if(nrow(lt.edges)) nwd <- deactivate.edges(nwd, onset=-Inf, terminus=lt.edges[,3], e=apply(lt.edges[,1:2,drop=FALSE],1,function(e) get.edgeIDs(nw, e[1], e[2])))
+    if(nrow(lt.edges)) nwd <- deactivate.edges(nwd, onset=-Inf, terminus=lt.edges[,3], e=apply(lt.edges[,1:2,drop=FALSE],1,function(e) get.edgeIDs(nwd, e[1], e[2])))
   }
   nwd<-delete.network.attribute(nwd, "time")
   nwd<-delete.network.attribute(nwd, "lasttoggle")
-  class(nwd) <- c("networkDynamic","network")
+  #class(nwd) <- c("networkDynamic","network")
   #attr(nwd,"end") <- nw %n% "time"
   
   nwd
