@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2008-2021 Statnet Commons
+#  Copyright 2008-2022 Statnet Commons
 ################################################################################
 #' @import statnet.common
 .onAttach <- function(libname, pkgname){
@@ -20,6 +20,7 @@
   eval(COLLATE_ALL_MY_CONTROLS_EXPR)
 
   .RegisterProposals()
+  .RegisterKeywords()
 }
 
 # TODO: Figure out some automatic way to keep this in sync with statnet.common.
@@ -46,3 +47,7 @@ eval(UPDATE_MY_SCTRL_EXPR)
   ergm_proposal_table("t", "Bernoulli", "|discord&sparse",  1, "discordTNT", "discordTNT")
   ergm_proposal_table("t", "Bernoulli", "|bdmax|blocks|strat|discord&sparse",  0, "discordBDStratTNT", "discordBDStratTNT")
 }
+
+.RegisterKeywords <- function() {
+  ergm_keyword(name='durational', short='dur', description="", popular=TRUE, package="tergm")
+}
